@@ -19,7 +19,7 @@ except ImportError:
 from sql import Literal
 from sql.aggregate import Count
 from sql.functions import Substring, Position
-from genshi.template import MarkupTemplate
+from genshi.template import MarkupTemplate, TextTemplate
 from genshi.core import START, END, QName, Attrs
 
 from trytond.config import config
@@ -315,7 +315,10 @@ class Activity(ModelSQL, ModelView):
             'invisible': Eval('action') != 'send_email',
             'required': Eval('action') == 'send_email',
             },
-        depends=['action'])
+        depends=['action'],
+        help="The subject of the email.\n"
+        "The Genshi syntax can be used "
+        "with 'record' in the evaluation context.")
     email_template = fields.Text(
         "E-Mail Template",
         translate=True,
@@ -445,6 +448,7 @@ class Activity(ModelSQL, ModelView):
         super().validate(activities)
         for activity in activities:
             activity.check_condition()
+            activity.check_email_title()
             activity.check_email_template()
 
     def check_condition(self):
@@ -471,15 +475,23 @@ class Activity(ModelSQL, ModelView):
                     activity=self.rec_name,
                     exception=exception)) from exception
 
+    def check_email_title(self):
+        if not self.email_title:
+            return
+        try:
+            TextTemplate(self.email_title)
+        except Exception as exception:
+            raise TemplateError(
+                gettext('marketing_automation'
+                    '.msg_activity_invalid_email_title',
+                    activity=self.rec_name,
+                    exception=exception)) from exception
+
     def execute(self, activity, **kwargs):
         pool = Pool()
         RecordActivity = pool.get('marketing.automation.record.activity')
         record = activity.record
 
-        # As it is a reference, the record may have been deleted
-        if not record:
-            return
-
         # XXX: use domain
         if self.condition and not record.eval(self.condition):
             return
@@ -532,7 +544,7 @@ class Activity(ModelSQL, ModelView):
             parts = urlsplit(urljoin(
                     URL_BASE, quote('/m/%(database)s/unsubscribe' % {
                             'database': Base64Converter(None).to_url(
-                                Transaction().database.name),
+                                Transaction().database.name).decode('utf-8'),
                             })))
             query = parse_qsl(parts.query)
             query.append(('r', record.uuid))
@@ -573,6 +585,9 @@ class Activity(ModelSQL, ModelView):
                     yield END, QName('img'), pos
                 yield kind, data, pos
 
+        title = (TextTemplate(translated.email_title)
+            .generate(record=record.record)
+            .render())
         template = MarkupTemplate(translated.email_template)
         content = (template
             .generate(record=record.record)
@@ -580,9 +595,11 @@ class Activity(ModelSQL, ModelView):
             .render())
 
         msg = MIMEMultipart('alternative')
-        msg['From'] = self.email_from or config.get('email', 'from')
+        msg['From'] = (self.email_from
+            or config.get('marketing', 'email_from')
+            or config.get('email', 'from'))
         msg['To'] = to
-        msg['Subject'] = Header(translated.email_title, 'utf-8')
+        msg['Subject'] = Header(title, 'utf-8')
         if html2text:
             converter = html2text.HTML2Text()
             part = MIMEText(
@@ -633,10 +650,9 @@ class Record(ModelSQL, ModelView):
     def get_models(self):
         pool = Pool()
         Model = pool.get('ir.model')
-        Scenario = pool.get('marketing.automation.scenario')
 
         if not self.scenario:
-            return Scenario.get_models()
+            return [('', '')]
 
         model, = Model.search([
                 ('model', '=', self.scenario.model),
@@ -675,10 +691,7 @@ class Record(ModelSQL, ModelView):
         cls.write(records, {'blocked': True})
 
     def get_rec_name(self, name):
-        if self.record:
-            return self.record.rec_name
-        else:
-            return '(%s)' % self.id
+        return self.record.rec_name
 
     @classmethod
     def create(cls, vlist):
